@@ -2,6 +2,7 @@
 #include <string.h>
 #include <glib.h>
 #include <gmpc/plugin.h>
+#include <config.h>
 #define QOSD_SONG_MARKUP "[[<span size=\"large\">♪ %title% ♪</span>\n]<span size=\"x-small\">[<i>artist:</i> %artist% ][<i>album:</i> %album%]</span>]|[%name%]|[%shortfile%]"
 
 
@@ -21,20 +22,13 @@ gmpcPrefPlugin qosd_gpp = {
 int plugin_api_version = PLUGIN_API_VERSION;
 /* main plugin_osd info */
 gmpcPlugin plugin = {
-	"Qball's On Screen Display",
-	{0,15,0},
-	GMPC_PLUGIN_NO_GUI,
-	0,
-	NULL, 
-	NULL,/*init */ 
-        NULL, /* Destroy */
-	NULL,
-	&qosd_mpd_status_changed,
-	NULL,
-	&qosd_gpp,
-	NULL,/* metadata */
-	qosd_get_enabled,
-	qosd_set_enabled	
+	.name           = "Qball's On Screen Display",
+	.version        = {PLUGIN_MAJOR_VERSION,PLUGIN_MINOR_VERSION,PLUGIN_MICRO_VERSION},
+	.plugin_type    = GMPC_PLUGIN_NO_GUI,
+	.mpd_status_changed = &qosd_mpd_status_changed,
+	.pref           = &qosd_gpp,
+	.get_enabled    = qosd_get_enabled,
+	.set_enabled    = qosd_set_enabled	
 };
 
 
